#

##

    	objectives

    		[ ] process level alerts variable

    				vegan_physics.py {
    					"alert level": "emergency"
    				}

    				levels:
    					"emergency"
    					"caution"
    					"info"
    					"scholar"

    				summary:
    					"emergency" is [ "emergency" ]

    					"caution" is [ "emergency", "caution" ]

    					"info" is [ "emergency", "caution", "info" ]

    					"scholar" is [ "emergency", "caution", "info", "scholar" ]

    		[ ] hatch as build system

    		[ ] lint

    		[ ] how to obtain?

    				pip install vegan

    				/vegan_adventure
    					/modules_pip
    						/vegan

    					essence.py

    					[sh] vegan adventures on
    					[sh] vegan adventures monetary saves import --name 3.JSON

    		[ ]
    			vegan ["retrieve food"] ()
    			[GET] /retrieve_food
    			[WS] "retrieve food"

    		[ ] mongo instead of tinydb

    			[ ] save & rebuild, export & dump

    			[ ] two URLs
    				( ) mongo besties URL
    				( ) local URL

    		[ ] essence
    			( ) from path
    			( ) configurable in memory

    			[ ] search "essence.py" in CWD by preset

    		[ ] food treasure:nature from mongo ingredients

    		[ ] supp treasure:nature from mongo ingredients

    		itinerary, ranked:
    			[ ] fractional amounts of essentials

    			[ ] supp, fractional amounts of measured ingredients

    			maybe:
    				[ ] food, fractional amounts of measured ingredients

    			[ ] besties/food_USDA/nature_v2/_status/status_2_form.py

    					change serving size unit to "grams" from "g"?

    		possibilities

    			[ ] 100% organic eco-friendly from sustainable farming.

    			instances:
    				programmatic:
    					import vegan
    					vegan_1 = vegan.instantiate ()

    				click:
    					[xonsh] vegan instantiate